==> flutter_kz_library-0.0.9.tar.gz: example/lib/src/screens/notification/NotificationPage.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_kz_library/flutter_kz_library.dart';

class NotificationPage extends StatefulWidget {
  @override
  _NotificationPageState createState() => _NotificationPageState();
}

class _NotificationPageState extends State<NotificationPage> {
  List<ItemPage> dumpList;

  Widget itemBuilderRender(BuildContext context, ItemPage entry, int index) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: 20.0),
      decoration: BoxDecoration(
        color: Colors.white,
        border: Border.all(width: 0, color: Colors.white),
        borderRadius: BorderRadius.only(
          topLeft: Radius.circular(index == 0 ? 20.0 : 0.0),
          topRight: Radius.circular(index == 0 ? 20.0 : 0.0),
        ),
      ),
      child: CardRoundRectangleBorderWidget(
          bolderColor: Colors.deepPurple,
          index: index,
          child: (index) => ListTile(
                title: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    Text(entry.title,
                        style: TextStyle(fontWeight: FontWeight.bold)),
                  ],
                ),
              )),
    );
  }

  List<ItemPage> pageData(
      int pageIndex, int pageSize, String token) {
    pageIndex = pageIndex == 0 ? 1 : pageIndex;

    List<ItemPage> dumpList = List();

    for (int i = pageIndex - 1; i < (pageIndex - 1) * pageSize; i++) {


    }

    return dumpList;
  }

  @override
  Widget build(BuildContext context) {
    return SliverViewPageWidget<ItemPage>(
      backGroundColor: Colors.deepPurple,
      expandedHeightPercent: 16,
      dataPinnedHeader: Text('Notifications'),
      dataPinnedLeading: Icon(Icons.notifications),
      dataBackground: Column(
        children: <Widget>[
          ListTile(
            title: Text(
              'Notifications',
              style: TextStyle(
                color: Colors.white,
                fontSize: 32.0,
                fontWeight: FontWeight.w700,
              ),
            ),
          ),
        ],
      ),
      pageSize: 10,
      itemBuilder: (context, entry, index) =>
          itemBuilderRender(context, entry, index),
    );
  }
}

class ItemPage {
  String title;
}

==> flutter_kz_library-0.1.1.tar.gz: example/lib/src/screens/notification/NotificationPage.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_kz_library/flutter_kz_library.dart';

class NotificationPage extends StatefulWidget {
  NotificationPage({Key key}) : super(key: key);

  @override
  _NotificationPageState createState() => _NotificationPageState();
}

class _NotificationPageState extends State<NotificationPage> {
  Widget itemBuilderRender(BuildContext context, ItemPage entry, int index) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: 20.0),
      decoration: BoxDecoration(
        color: Colors.white,
        border: Border.all(width: 0, color: Colors.white),
        borderRadius: BorderRadius.only(
          topLeft: Radius.circular(index == 0 ? 20.0 : 0.0),
          topRight: Radius.circular(index == 0 ? 20.0 : 0.0),
        ),
      ),
      child: CardRoundRectangleBorderWidget(
          bolderColor: Colors.deepPurple,
          index: index,
          child: (index) => ListTile(
                title: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    Text(entry.title,
                        style: TextStyle(fontWeight: FontWeight.bold)),
                  ],
                ),
              )),
    );
  }

  Future<List<ItemPage>> pageData(
      int pageIndex, int pageSize) async {

    List<ItemPage> dumpList = List();

    for (int i = pageIndex * pageSize; i < (pageIndex + 1) * pageSize; i++) {

      dumpList.add(ItemPage(title: 'title $i'));

    }

    print(dumpList);

    return dumpList;
  }

  @override
  Widget build(BuildContext context) {
    return SliverViewPageWidget<ItemPage>(
      backGroundColor: Colors.purple,
      expandedHeightPercent: 16,
      dataPinnedHeader: Text('Notifications'),
      dataPinnedLeading: Icon(Icons.notifications),
      dataBackground: Column(
        children: <Widget>[
          ListTile(
            title: Text(
              'Notifications',
              style: TextStyle(
                color: Colors.white,
                fontSize: 32.0,
                fontWeight: FontWeight.w700,
              ),
            ),
          ),
        ],
      ),
      pageSize: 10,
      itemBuilder: (context, entry, index) =>
          itemBuilderRender(context, entry, index),
      pageFuture: (pageIndex, pageSize) =>
          pageData(pageIndex, pageSize),
    );
  }
}

class ItemPage {
  String title;

  ItemPage({this.title});
}
